# DuckGuard — Orders Quality Report (Dark)

Source: c:\SourceCode\SophonDataHub\duckguard\examples\sample_data\orders.csv | Generated: 2026-01-30 22:35:04
Rows: 30 | Columns: 15 | Duration: 355ms
✗ FAILED
Quality Score
64.7%
Grade: D
Checks Passed
11
of 17 total
Failures
4
Warnings
2
Quality Score
65
Quality Trend (11 data points)
Failures (4)

Check | Column | Message | Actual | Expected
--- | --- | --- | --- | ---
✗ not_null | customer_id | Column 'customer_id' has 1 null values | `1` | `0`
✗ between | quantity | Column 'quantity' has 2 values outside [1, 1000] | `2` | `[1, 1000]`
✗ non_negative | subtotal | Column 'subtotal' min is -20.0 (expected >= 0) | `-20.0` | `>= 0`
✗ positive | total_amount | Column 'total_amount' has 1 values <= 0 | `1` | `> 0`

Warnings (2)

Check | Column | Message | Actual
--- | --- | --- | ---
⚠ not_null | email | Column 'email' has 2 null values | `2`
⚠ not_null | phone | Column 'phone' has 2 null values | `2`

Passed Checks (11)

Check | Column | Message
--- | --- | ---
✓ row_count | - | Row count is 30 (expected >= 10)
✓ not_null | order_id | Column 'order_id' has no null values
✓ unique | order_id | Column 'order_id' is 100% unique
✓ not_null | product_name | Column 'product_name' has no null values
✓ allowed_values | product_name | Column 'product_name' has 0 values not in allowed set
✓ positive | unit_price | Column 'unit_price' has all positive values
✓ not_null | status | Column 'status' has no null values
✓ allowed_values | status | Column 'status' has 0 values not in allowed set
✓ not_null | country | Column 'country' has no null values
✓ allowed_values | country | Column 'country' has 0 values not in allowed set
✓ not_null | created_at | Column 'created_at' has no null values